# Generated by the protocol buffer compiler.  DO NOT EDIT!
# Source: google/logging/v2/logging_metrics.proto for package 'Google.Cloud.Logging.V2'
# Original file comments:
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'grpc'
require 'google/logging/v2/logging_metrics_pb'

module Google
  module Cloud
    module Logging
      module V2
        module MetricsServiceV2
          # Service for configuring logs-based metrics.
          class Service

            include ::GRPC::GenericService

            self.marshal_class_method = :encode
            self.unmarshal_class_method = :decode
            self.service_name = 'google.logging.v2.MetricsServiceV2'

            # Lists logs-based metrics.
            rpc :ListLogMetrics, ::Google::Cloud::Logging::V2::ListLogMetricsRequest, ::Google::Cloud::Logging::V2::ListLogMetricsResponse
            # Gets a logs-based metric.
            rpc :GetLogMetric, ::Google::Cloud::Logging::V2::GetLogMetricRequest, ::Google::Cloud::Logging::V2::LogMetric
            # Creates a logs-based metric.
            rpc :CreateLogMetric, ::Google::Cloud::Logging::V2::CreateLogMetricRequest, ::Google::Cloud::Logging::V2::LogMetric
            # Creates or updates a logs-based metric.
            rpc :UpdateLogMetric, ::Google::Cloud::Logging::V2::UpdateLogMetricRequest, ::Google::Cloud::Logging::V2::LogMetric
            # Deletes a logs-based metric.
            rpc :DeleteLogMetric, ::Google::Cloud::Logging::V2::DeleteLogMetricRequest, ::Google::Protobuf::Empty
          end

          Stub = Service.rpc_stub_class
        end
      end
    end
  end
end
